@@ -70,7 +70,7 @@ namespace aspeller {
     , {"store-as",            KeyInfoString, "", ""}
     , {"try",                 KeyInfoString, "", ""}
     , {"normalize",           KeyInfoBool, "false", "", 0, FOR_CONFIG}
-    , {"norm-required",       KeyInfoBool, "false", "", }
+    , {"norm-required",       KeyInfoBool, "false", "", 0, FOR_CONFIG}
     , {"norm-form",           KeyInfoString, "nfc", "", 0, FOR_CONFIG}
   };
 
@@ -183,7 +183,11 @@ namespace aspeller {
       char_info_[i] = inf;
     }
 
-    to_plain_[0] = 1; // to make things slightly easier
+    for (unsigned int i = 0; i != 256; ++i) {
+      de_accent_[i] = to_plain_[i] == 0 ? to_uchar(i) : to_plain_[i];
+    }
+
+    to_plain_[0] = 1; // to make things slightly easier // FIXME: Should this be 0x10
     to_plain_[1] = 1;
 
     for (unsigned int i = 0; i != 256; ++i) {
@@ -295,7 +299,7 @@ namespace aspeller {
     return no_err;
   }
 
-  void Language::set_lang_defaults(Config & config)
+  void Language::set_lang_defaults(Config & config) const
   {
     config.replace_internal("actual-lang", name());
     StackPtr<KeyInfoEnumeration> els(lang_config_->possible_elements(false));
